=======
Credits
=======

Development Lead
----------------

* Andrew Cordery <cordery@gmail.com>

Contributors
------------

decibyte (Django 2.0 support, bug fixes)
sklirg (bug fixes)
blueyed (improved admin)
luiscberrocal (Python 3 support)
